@@ -5,9 +5,13 @@ import base64
 import gzip
 from StringIO import StringIO
 from urlparse import urlparse
+try:
+  import json
+except ImportError:
+  import simplejson as json
 from utils import json_to_py, get_faker
 
-__version_info__ = ('3', '0', '0')
+__version_info__ = ('3', '1', '0')
 __version__ = '.'.join(__version_info__)
 
 class CreateSendError(Exception):
@@ -61,7 +65,7 @@ class CreateSendBase(object):
       ('code', code),
     ]
     response = self._post('', urllib.urlencode(params),
-      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded", True)
+      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded")
     access_token, expires_in, refresh_token = None, None, None
     r = json_to_py(response)
     if hasattr(r, 'error') and hasattr(r, 'error_description'):
@@ -97,7 +101,7 @@ class CreateSendBase(object):
       ('refresh_token', refresh_token)
     ]
     response = self._post('', urllib.urlencode(params),
-      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded", True)
+      CreateSend.oauth_token_uri, "application/x-www-form-urlencoded")
     new_access_token, new_expires_in, new_refresh_token = None, None, None
     r = json_to_py(response)
     new_access_token, new_expires_in, new_refresh_token = r.access_token, r.expires_in, r.refresh_token
@@ -112,7 +116,7 @@ class CreateSendBase(object):
     self.faker = get_faker(expected_url, filename, status, body)
 
   def make_request(self, method, path, params={}, body="", username=None,
-    password=None, base_uri=None, content_type=None, no_auth=None):
+    password=None, base_uri=None, content_type=None):
     headers = {
       'User-Agent': 'createsend-python-%s' % __version__,
       'Content-Type': 'application/json; charset=utf-8',
@@ -130,8 +134,6 @@ class CreateSendBase(object):
         headers['Authorization'] = "Basic %s" % base64.b64encode("%s:x" % self.auth_details['api_key'])
       elif 'access_token' in self.auth_details and self.auth_details['access_token']:
         headers['Authorization'] = "Bearer %s" % self.auth_details['access_token']
-    if no_auth:
-      del headers['Authorization']
     self.headers = headers
 
     """If in fake web mode (i.e. self.stub_request has been called), 
@@ -187,7 +189,7 @@ class CreateSendBase(object):
   def _get(self, path, params={}, username=None, password=None):
     return self.make_request(path=path, method="GET", params=params, username=username, password=password)
 
-  def _post(self, path, body="", base_uri=None, content_type=None, no_auth=None):
+  def _post(self, path, body="", base_uri=None, content_type=None):
     return self.make_request(path=path, method="POST", body=body, 
       base_uri=base_uri, content_type=content_type)
 
@@ -239,17 +241,46 @@ class CreateSend(CreateSendBase):
     return json_to_py(response)
 
   def administrators(self):
-  	"""gets administrators associated with the account"""
+  	"""Gets administrators associated with the account"""
   	response = self._get('/admins.json')
   	return json_to_py(response)
   
   def get_primary_contact(self):
-  	"""retrieves the primary contact for this account"""
+  	"""Retrieves the primary contact for this account"""
   	response = self._get('/primarycontact.json')
   	return json_to_py(response)
 
   def set_primary_contact(self, email):
-    """assigns the primary contact for this account"""
+    """Assigns the primary contact for this account"""
     params = { "email": email }
     response = self._put('/primarycontact.json', params = params)
     return json_to_py(response)
+
+  def external_session_url(self, email, chrome, url, integrator_id, client_id):
+    """
+    Get a URL which initiates a new external session for the user with the
+    given email.
+    Full details: http://www.campaignmonitor.com/api/account/#single_sign_on
+
+    :param email: String The representing the email address of the
+      Campaign Monitor user for whom the login session should be created.
+    :param chrome: String representing which 'chrome' to display - Must be
+      either "all", "tabs", or "none".
+    :param url: String representing the URL to display once logged in.
+      e.g. "/subscribers/"
+    :param integrator_id: String representing the Integrator ID. You need to
+      contact Campaign Monitor support to get an Integrator ID.
+    :param client_id: String representing the Client ID of the client which
+      should be active once logged in to the Campaign Monitor account.
+
+    :returns Object containing a single field SessionUrl which represents
+    the URL to initiate the external Campaign Monitor session.
+    """
+    body = {
+      "Email": email, 
+      "Chrome": chrome,
+      "Url": url,
+      "IntegratorID": integrator_id,
+      "ClientID": client_id }
+    response = self._put('/externalsession.json', json.dumps(body))
+    return json_to_py(response)
