@@ -130,7 +130,7 @@ class ListTestCase(object):
     self.assertEquals(res.Results[0].CustomFields[2].Value, "option two")
     self.assertEquals(res.Results[0].ReadsEmailWith, "Gmail")
 
-  def test_active(self):
+  def test_unconfirmed(self):
     min_date = "2010-01-01"
     self.list.stub_request("lists/%s/unconfirmed.json?date=%s&orderfield=email&page=1&pagesize=1000&orderdirection=asc" % (self.list.list_id, urllib.quote(min_date)), "unconfirmed_subscribers.json")
     res = self.list.unconfirmed(min_date)
@@ -244,7 +244,7 @@ class OAuthListTestCase(unittest.TestCase, ListTestCase):
   def setUp(self):
     self.client_id = "87y8d7qyw8d7yq8w7ydwqwd"
     self.list_id = "e3c5f034d68744f7881fdccf13c2daee"
-    self.list = List({"access_token": "98u9q8uw9ddw", "refresh_token": "9u09i02e3"}, self.list_id)
+    self.list = List({"access_token": "ASP95S4aR+9KsgfHB0dapTYxNA==", "refresh_token": "5S4aASP9R+9KsgfHB0dapTYxNA=="}, self.list_id)
 
 class ApiKeyListTestCase(unittest.TestCase, ListTestCase):
   """Test when using an API key to authenticate"""
