@@ -111,7 +111,17 @@ class SubscriberTestCase(object):
     self.assertEquals(import_result.TotalNewSubscribers, 0)
     self.assertEquals(len(import_result.DuplicateEmailsInSubmission), 0)
 
-  def test_ubsubscribe(self):
+  def test_import_subscribers_complete_failure_because_of_bad_request(self):
+    # Stub request with 400 Bad Request as the expected response status
+    self.subscriber.stub_request("subscribers/%s/import.json" % self.list_id, "custom_api_error.json", 400)
+    subscribers = [
+      { "EmailAddress": "example+1@example", "Name": "Example One" },
+      { "EmailAddress": "example+2@example.com", "Name": "Example Two" },
+      { "EmailAddress": "example+3@example.com", "Name": "Example Three" },
+    ]
+    self.assertRaises(BadRequest, self.subscriber.import_subscribers, self.list_id, subscribers, True)
+
+  def test_unsubscribe(self):
     self.subscriber.stub_request("subscribers/%s/unsubscribe.json" % self.list_id, None)
     self.subscriber.unsubscribe()
 
@@ -128,12 +138,16 @@ class SubscriberTestCase(object):
     self.assertEquals(history[0].Actions[0].IPAddress, "192.168.126.87")
     self.assertEquals(history[0].Actions[0].Detail, "")
 
+  def test_delete(self):
+    self.subscriber.stub_request("subscribers/%s.json?email=%s" % (self.list_id, urllib.quote(self.subscriber.email_address)), None)
+    self.subscriber.delete()
+
 class OAuthSubscriberTestCase(unittest.TestCase, SubscriberTestCase):
   """Test when using OAuth to authenticate"""
   def setUp(self):
     self.list_id = "d98h2938d9283d982u3d98u88"
     self.subscriber = Subscriber(
-      {"access_token": "98u9q8uw9ddw", "refresh_token": "9u09i02e3"},
+      {"access_token": "ASP95S4aR+9KsgfHB0dapTYxNA==", "refresh_token": "5S4aASP9R+9KsgfHB0dapTYxNA=="},
       self.list_id, "subscriber@example.com")
 
 class ApiKeySubscriberTestCase(unittest.TestCase, SubscriberTestCase):
